*************
Assortativity
*************

.. automodule:: networkx.algorithms.assortativity
.. autosummary::
   :toctree: generated/

Assortativity
-------------   
.. autosummary::
   :toctree: generated/

   degree_assortativity_coefficient
   attribute_assortativity_coefficient
   numeric_assortativity_coefficient
   degree_pearson_correlation_coefficient

Average neighbor degree
-----------------------   
.. autosummary::
   :toctree: generated/

   average_neighbor_degree


Average degree connectivity
---------------------------
.. autosummary::
   :toctree: generated/

   average_degree_connectivity
   k_nearest_neighbors


Mixing
------
.. autosummary::
   :toctree: generated/

   attribute_mixing_matrix
   degree_mixing_matrix
   numeric_mixing_matrix
   attribute_mixing_dict
   degree_mixing_dict
   mixing_dict
